# Nexus Skin for Ensim Pro - Nexus.py
#
# Adapted from Mercury Skin - Copyright (c) 2000-2003 Ensim Corporation.
#
# Portions Copyright (c) 2003-2004 Interjuncture. All rights reserved.
# http://www.interjuncture.com/software/ensim/
#
import os
import string
import copy
import stat
import mimetypes
from rfcdate import rfc1123_date

import ensimapplpath
import skin
import dashboard
import requestutil
import convertunits
import fileman
import sessionman

class Skin(skin.SkinBase):
    
    def user_frame(self):
        r = self.get_response()
        site,user = requestutil.get_site_user_from_request(self.REQUEST)
        uaconf = dashboard.get_user_conf(site,user)
        dashboard.load_user_request(self.REQUEST, uaconf)
        self.load_common_translations(uaconf)
        
        a = r.write('''
<HTML>
<HEAD>
<base href="https://%(http_host)s/webhost/services/virtualhosting/useradmin/" />
<!----- Copyright (c) 2000-2003 Ensim Corporation ----->
<!----- Portions (c) 2003 Interjuncture. All rights reserved. ----->
<TITLE>%(T_User_Administrator)s %(display_version)s (%(login_name)s)</TITLE>
</HEAD>

<FRAMESET rows="50,30,*" cols="*" framespacing="0" frameborder="no" border="0">
  <FRAME src="topbar" name="top" frameborder="no" scrolling="no" noresize marginwidth="0" marginheight="0" id="top">
  <FRAMESET cols="175,*" framespacing="0" frameborder="no" border="0">
     <FRAME ID=who name=who src="who" frameborder=no noresize scrolling=no marginwidth="0" marginheight="0">
     <FRAME id=quicksearch name=quicksearch src="quicksearch" frameborder=no noresize scrolling=no marginwidth="0" marginheight="0">
  </FRAMESET>
  <FRAMESET cols="175,1,*" framespacing="0" frameborder="no" border="0">
     <FRAME src="navbar" name="navigation" frameborder="no" scrolling="no" noresize marginwidth="0" marginheight="0" id="navigation">
     <FRAME id=brdr name=brdr src="border" frameborder=no scrolling=no noresize marginwidth="0" marginheight="0" border=0 framspacing="0">
     <FRAME id=main name=main src="view_shortcuts" frameborder=no noresize scrolling=auto marginwidth="5" marginheight="5">
  </FRAMESET>
</FRAMESET>
<NOFRAMES>
%(frames_warning)s
</NOFRAMES>
</HTML>''' % uaconf)

    def site_frame(self):
        r = self.get_response()
        site = requestutil.get_site_from_request(self.REQUEST)
        saconf = dashboard.get_site_conf(site)
        dashboard.load_site_request(self.REQUEST, saconf)
        self.load_common_translations(saconf)
        a = r.write('''
<HTML>
<HEAD>
<base href="https://%(http_host)s/webhost/services/virtualhosting/siteadmin/" />
<!----- Copyright (c) 2000-2003 Ensim Corporation ----->
<!----- Portions (c) 2003 Interjuncture. All rights reserved. ----->
<TITLE>%(T_Site_Administrator)s %(display_version)s (%(login_name)s)</TITLE>
</HEAD>

<frameset rows="50,30,*" cols="*" framespacing="0" frameborder="no" border="0">
  <frame src="topbar" name="top" frameborder="no" scrolling="no" noresize marginwidth="0" marginheight="0" id="top">
  <frameset cols="175,*" framespacing="0" frameborder="no" border="0">
  <FRAME ID=who name=who src="who" frameborder=no noresize scrolling=no marginwidth="0" marginheight="0">
  <FRAME id=quicksearch name=quicksearch src="quicksearch" frameborder=no noresize scrolling=no marginwidth="0" 
	marginheight="0">
  </frameset>
  <frameset cols="175,1,*" framespacing="0" frameborder="no" border="0">
     <frame src="navbar" name="navigation" frameborder="no" scrolling="no" noresize marginwidth="0" marginheight="0" 
	id="navigation">
     <FRAME id=brdr name=brdr src="border" frameborder=no scrolling=no noresize marginwidth="0" marginheight="0" border=0 
	framspacing="0">
     <FRAME id=main name=main src="view_shortcuts" frameborder=no noresize scrolling=auto marginwidth="5" marginheight="5">
  </FRAMESET>
</frameset>


<noframes>
%(frames_warning)s
</noframes>
</HTML>''' % saconf)

    def reseller_frame(self):
        r = self.get_response()

        username = requestutil.get_reseller_from_request(self.REQUEST)
        raconf = dashboard.get_reseller_conf(username)
        dashboard.load_reseller_request(self.REQUEST, raconf)
        
        self.load_common_translations(raconf)
        
        a = r.write('''
<HTML>
<HEAD>
<base href="https://%(http_host)s/webhost/services/reseller/resellercp/" />
<!----- Copyright (c) 2000-2003 Ensim Corporation ----->
<!----- Portions (c) 2003 Interjuncture. All rights reserved. ----->
<TITLE>%(T_Reseller_Administrator)s %(display_version)s (%(login_name)s)</TITLE>
</HEAD>
<frameset rows="50,30,*" cols="*" framespacing="0" frameborder="no" border="0">
  <frame src="topbar" name="top" frameborder="no" scrolling="no" noresize marginwidth="0" marginheight="0" id="top">
  <frameset cols="175,*" framespacing="0" frameborder="no" border="0">
  <FRAME ID=who name=who src="who" frameborder=no noresize scrolling=no marginwidth="0" marginheight="0">
  <FRAME id=quicksearch name=quicksearch src="quicksearch" frameborder=no noresize scrolling=no marginwidth="0"
        marginheight="0">
  </frameset>
  <frameset cols="175,1,*" framespacing="0" frameborder="no" border="0">
    <frame src="navbar" name="navigation" frameborder="no" scrolling="no" noresize marginwidth="0" marginheight="0" id="navigation">
    <frame id=border2 name=border2 src="border" frameborder=no noresize scrolling=no>
    <frame src="view_shortcuts" name="main" frameborder="no" scrolling="auto" noresize marginwidth="0" marginheight="0" id="main" >
  </frameset>
</frameset>
<noframes>
%(frames_warning)s
</noframes>
</HTML>''' % raconf)

       
    def appliance_frame(self):
        r = self.get_response()
        
        aaconf = dashboard.get_appliance_conf()
        dashboard.load_appliance_request(self.REQUEST, aaconf)
        
        self.load_common_translations(aaconf)
        a = r.write('''
<HTML>
<HEAD>
<base href="https://%(http_host)s/webhost/" />
<!----- Copyright (c) 2000-2003 Ensim Corporation ----->
<!----- Portions (c) 2003 Interjuncture. All rights reserved. ----->
<TITLE>%(T_Appliance_Administrator)s %(display_version)s (%(login_name)s)</TITLE>
</HEAD>
<frameset rows="50,30,*" cols="*" framespacing="0" frameborder="no" border="0">
  <frame src="topbar" name="top" frameborder="no" scrolling="no" noresize marginwidth="0" marginheight="0" id="top">
  <frameset cols="175,*" framespacing="0" frameborder="no" border="0">
  <FRAME ID=who name=who src="who" frameborder=no noresize scrolling=no marginwidth="0" marginheight="0">
  <FRAME id=quicksearch name=quicksearch src="quicksearch" frameborder=no noresize scrolling=no marginwidth="0" marginheight="0">
  </frameset>
  <frameset cols="175,1,*" framespacing="0" frameborder="no" border="0">
     <frame src="navbar" name="navigation" frameborder="no" scrolling="no" noresize marginwidth="0" marginheight="0" id="navigation">
     <FRAME id=brdr name=brdr src="border" frameborder=no scrolling=no noresize marginwidth="0" marginheight="0" border=0 framespacing=0>
     <FRAME id=main name=main src="view_shortcuts" frameborder=no noresize scrolling=auto marginwidth="5" marginheight="5">
  </FRAMESET>
</frameset>
<noframes>
%(frames_warning)s
</noframes>
</HTML>''' % aaconf)

    def get_stylesheet_path(self):
        return os.path.join(self.skin_base_dir, 'css', 'global.css')

###################### splash screen #########################
    def get_firstpage_status(self,REQUEST):
        enabled = 0
        sitesession = sessionman.getSession(REQUEST)
        if sitesession.has_key('showpage'):
            if int(sitesession['showpage'])==1:
                enabled = 1
            del sitesession['showpage']
        REQUEST['showpage'] = enabled
  

    def display_firsttimeuser_window(self):
        enabled = 1
        sitesession = sessionman.getSession(self.REQUEST)
        if sitesession.has_key('homedir'): 
            site_path = sitesession['homedir']
        else:
            # this condition will never occur.   
            site_path =""

        file_path = site_path + "/etc/firsttimeuser"
        if os.path.isfile(file_path):
            ret,dict = MyConfigParser.read_conf(file_path)
            if ret:
                enabled=1 
            else:
                if ((dict.has_key('showpage')) and (int(dict['showpage'])==1)):
                    enabled=1
                else:
                    enabled=0
        else:
            # This is the first login. Hence show the pop up and also create the file
            enabled=1
            fptr=open(file_path,"w")
            fptr.write("[DEFAULT]\nshowpage=1\n")
            fptr.close()
        return enabled

    def manage_show_page(self,REQUEST):
        """ first time user"""
        formdata = REQUEST.form
        sitesession = sessionman.getSession(self.REQUEST)
        if sitesession.has_key('homedir'): 
            site_path = sitesession['homedir']
        else:
            # this condition will never occur.   
            site_path =""
        file_path = site_path + "/etc/firsttimeuser"

        if ((formdata.has_key('display_window')) and (formdata['display_window']=='on')):
            # dont show this window again 
            fptr=open(file_path,"w")
            fptr.write("[DEFAULT]\nshowpage=0\n")
            fptr.close()
        else:
            fptr=open(file_path,"w")
            fptr.write("[DEFAULT]\nshowpage=1\n")
            fptr.close()
        REQUEST.RESPONSE.redirect('new_user_close_form')

##############################################################
